@@ -2,9 +2,9 @@
 use Modern::Perl;
 use Moose::Util qw( with_traits );
 use lib '../lib', 'lib';
-use Data::Walk::Extracted v0.015;
-use Data::Walk::Graft v0.009;
-use Data::Walk::Print v0.009;
+use Data::Walk::Extracted 0.019;
+use Data::Walk::Graft 0.013;
+use Data::Walk::Print 0.015;
 
 my  $gardener = with_traits( 
         'Data::Walk::Extracted', 
@@ -14,13 +14,15 @@ my  $gardener = with_traits(
             'Data::Walk::Print',
         ) 
     )->new(
-		sort_HASH => 1,# For demonstration consistency
+		sorted_nodes =>{
+			HASH => 1,
+		},# For demonstration consistency
 		#Until Data::Walk::Extracted and ::Graft support these types
 		#(watch Data-Walk-Extracted on github)
-		dont_clone_node_types =>[ 
-			'OBJECT',
-			'CODEREF',
-		],
+		skipped_nodes =>{ 
+			OBJECT => 1,
+			CODEREF => 1,
+		},
 		graft_memory => 1,
 	);
 my  $tree_ref = {
